@@ -29,18 +29,19 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Sun 31 Aug 2008 03:24:00 JST
+ *  Last-modified: Sat 14 Mar 2009 21:19:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_SHA1_H
 #define CLX_SHA1_H
 
-#include <iostream>
-#include <iomanip>
 #include <cstring>
 #include <climits>
+#include <iostream>
+#include <iomanip>
 #include <string>
 #include <sstream>
+#include "memory.h"
 
 #ifndef ROTATE_LEFT
 #define ROTATE_LEFT(x, n) (((x) << (n)) | ((x) >> (32 - n)))
@@ -110,7 +111,7 @@ namespace clx {
 			if (count_[0] < n) ++count_[1];
 			
 			if (left > 0 && n >= fill) {
-				std::memcpy(buffer_ + left, block, fill);
+				clx::memcpy(buffer_ + left, block, fill);
 				this->calculate(buffer_, w_);
 				n -= fill;
 				block += fill;
@@ -123,15 +124,15 @@ namespace clx {
 				block += 64;
 			}
 			
-			if (n > 0) std::memcpy(buffer_ + left, block, n);
+			if (n > 0) clx::memcpy(buffer_ + left, block, n);
 		}
 		
 		void finish() {
 			uint32_t high = REVERSE_ENDIAN((count_[0] >> 29) | (count_[1] << 3));
 			uint32_t low = REVERSE_ENDIAN(count_[0] << 3);
 			uchar_t nbit[8];
-			std::memcpy(nbit, (uchar_t*)&high, 4);
-			std::memcpy(&nbit[4], (uchar_t*)&low, 4);
+			clx::memcpy(nbit, &high, 4);
+			clx::memcpy(&nbit[4], &low, 4);
 			
 			uint32_t last = count_[0] & 0x3f;
 			uint32_t padn = (last < 56) ? (56 - last) : (120 - last);
@@ -188,7 +189,7 @@ namespace clx {
 		
 		static void calculate(const uchar_t* block, uint32_t* code) {
 			uint32_t x[16];
-			std::memcpy((uchar_t*)x, block, sizeof(x));
+			clx::memcpy(x, block, sizeof(x));
 			
 			uint32_t w[80];
 			for (int i = 0; i < 16; ++i) w[i] = REVERSE_ENDIAN(x[i]);
