@@ -46,7 +46,7 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		template <class InIter>
 		inline size_t get(InIter& first, InIter last) {
-			if (first == last) return 0;
+			if (first == last) return size_t(-1);
 			
 			size_t dest = 0;
 			size_t n = 0;
@@ -59,11 +59,13 @@ namespace clx {
 			else if (c >= 0xf8 && c <= 0xfb) n = 5;
 			else if (c >= 0xfc && c <= 0xfd) n = 6;
 #endif
-			else throw std::runtime_error("invalid UTF8 character code");
+			else throw std::runtime_error("invalid UTF-8 character code");
 			
 			dest = 0;
 			for (size_t i = 0; i < n && first != last; ++i, ++first) {
-				dest |= (*first & 0xff) << (i * 8);
+				c = *first & 0xff;
+				if (i > 0 && !(c >= 0x80 && c <= 0xbf)) throw std::runtime_error("invalid UTF-8 character code");
+				dest |= c << (i * 8);
 			}
 			
 			return dest;
@@ -86,9 +88,11 @@ namespace clx {
 			else if (c >= 0xf8 && c <= 0xfb) n = 5;
 			else if (c >= 0xfc && c <= 0xfd) n = 6;
 #endif
-			else throw std::runtime_error("invalid UTF8 character code");
+			else throw std::runtime_error("invalid UTF-8 character code");
 			
 			for (size_t i = 0; i < n && first != last; ++i, ++first) {
+				c = *first & 0xff;
+				if (i > 0 && !(c >= 0x80 && c <= 0xbf)) throw std::runtime_error("invalid UTF-8 character code");
 				out = *first;
 				++out;
 			}
@@ -153,7 +157,7 @@ namespace clx {
 				else if (c >= 0xf8 && c <= 0xfb) std::advance(pos, 5);
 				else if (c >= 0xfc && c <= 0xfd) std::advance(pos, 6);
 #endif
-				else throw std::runtime_error("invalid UTF8 character code");
+				else throw std::runtime_error("invalid UTF-8 character code");
 			}
 		}
 		
@@ -174,7 +178,7 @@ namespace clx {
 				else if (c >= 0xf8 && c <= 0xfb) std::advance(first, 5);
 				else if (c >= 0xfc && c <= 0xfd) std::advance(first, 6);
 #endif
-				else throw std::runtime_error("invalid UTF8 character code");
+				else throw std::runtime_error("invalid UTF-8 character code");
 			}
 			return dest;
 		}
