@@ -93,13 +93,7 @@ namespace clx {
 		explicit thread(Functor f, bool detached = false) :
 			data_(new inherit_data<Functor>(f)), id_() {
 			data_->joined = detached;
-			try {
-				this->start();
-			}
-			catch (system_error& e) {
-				data_ = detail::thread_data_ptr();
-				throw e;
-			}
+			this->start();
 		}
 		
 		virtual ~thread() throw() {
